Module exec

Module exec 

Modules

arith
Arithmetic
bitman
Bit manipulation
cmp
Comparison
io
I/O
mov
Data movement

Structs

Context
Tracks state of the registers and memory during execution
DebugInfo
Struct to store original labels of shuffled addresses
ExecInst
Runtime representation of an instruction
Executor
Executes a program
Io
For platform independent I/O
Memory
Struct providing random-access memory (RAM)
Stores original source code during execution

Enums

RtError
Represents all possible runtime errors
Status
Shows execution status

Type Aliases

ExTree
Runtime representation of a program
ExecFunc
Function pointer of an instruction called with Context and Op at runtime
RtResult